@@ -13,7 +13,7 @@ class I18n(Feature):
         self.fallback_translations = fallback_translations
 
         try:
-            Schema(((str, str),))(langs)
+            Schema(((str, basestring),))(langs)
         except MultipleInvalid as e:
             self.report_failure('Parameter "langs" validation error: %s' % str(e))
 
