@@ -1,6 +1,7 @@
 """
 Default settings for cratis project
 """
+import logging
 import os
 import pywizard.api as pw
 
@@ -9,12 +10,15 @@ import sys
 from pywizard.context import Context
 from pywizard.cli import yn_choice
 
+import inject
+
 
 class Common(Configuration):
 
     @classmethod
     def load_features(cls):
         loaded_features = []
+
         for feature in cls.FEATURES:
 
             for requirement in feature.get_required(cls):
@@ -71,6 +75,22 @@ class Common(Configuration):
 
                 exit(1)
 
+    @classmethod
+    def post_setup(cls):
+        super(Common, cls).post_setup()
+
+        def configure_feature_services(binder):
+            for feature in cls.FEATURES:
+                feature.append_services(binder)
+
+        inject.configure(configure_feature_services)
+
+        for feature in cls.FEATURES:
+            feature.on_startup()
+
+
+    FEATURES = ()
+
 
     # Build paths inside the project like this: os.path.join(BASE_DIR, ...)
     BASE_DIR = os.environ.get('CRATIS_APP_PATH', '.')
@@ -145,25 +165,4 @@ class Common(Configuration):
     STATICFILES_DIRS = ()
     TEMPLATE_DIRS = ()
 
-    FEATURES = ()
     SITE_ID = 1
-
-
-class CratisDev(Common):
-    """
-    The in-development settings and the default configuration.
-    """
-    pass
-
-
-class CratisProd(Common):
-    """
-    The in-production settings.
-    """
-    DEBUG = False
-    TEMPLATE_DEBUG = DEBUG
-
-    SECRET_KEY = values.SecretValue()
-
-Dev = CratisDev
-Prod = CratisProd
\ No newline at end of file
